#
# spec file for package python-sigal
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without test
Name:           python-sigal
Version:        1.4.0
Release:        3.1
Summary:        Static gallery generator
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/saimn/sigal
Source:         https://files.pythonhosted.org/packages/source/s/sigal/sigal-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Jinja2
Requires:       python-Markdown
Requires:       python-Pillow
Requires:       python-blinker
Requires:       python-click
Requires:       python-pilkit
Suggests:       python-boto
Suggests:       python-cssmin
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module Markdown}
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module blinker}
BuildRequires:  %{python_module click}
BuildRequires:  %{python_module pilkit}
%endif
%python_subpackages

%description
Sigal is a static gallery generator written in Python with the following
features:

* Generates HTML pages using jinja2 templates.
* Emits relative links for a portable output.
* Supports themes, videos, EXIF tags, and ZIP downloading.
* Processes directories recursively and files in parallel.

The idea behind Sigal is to ease the use of the JavaScript libraries like
galleria_. These libraries display the images, Sigal on the other hand does
image resizing, thumbnail creation and HTML page generation.

%prep
%setup -q -n sigal-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%license LICENSE
%doc AUTHORS README.rst
%python3_only %{_bindir}/sigal
%{python_sitelib}/*

%changelog
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Tue Apr 24 2018 tbechtold@suse.com
- update to 1.4.0:
  - Update libraries used in themes (Galleria, Colorbox, PhotoSwipe) and their
    dependencies.
  - Remove use of CDNs (JQuery, Google fonts).
  - Hint to how to suppress decompressionbomb warnings [:issue:`235`].
  - New plugin for finer control over ignored files [:issue:`233`].
  - New plugin to cache the exif data of images [:issue:`236`].
  - Feeds plugin: include videos in feeds [:issue:`238`].
  - Allow formatting in ``zip_gallery`` [:issue:`244`].
  - Added random thumbnail property for album [:issue:`241`].
  - Improve CSP compatibility with colorbox theme [:issue:`245`].
  - Set html lang attribute based upon locale [:issue:`257`].
  - Resize portrait images to same size as landscape [:issue:`258`].
  - New setting ``thumb_fit_centering`` for tweaking how thumbnails should be
    cropped [:issue:`263`].
  - New settings to configure what file extensions should be recognised as
    images and videos [:issue:`270`].
  - New setting ``datetime_format`` to customize the EXIF datetime format
    [:issue:`271`].
  - Add a progress bar for writing index files [:issue:`234`].
  - Add setting to customize the EXIF datetime format [:issue:`271`].
  - Allow to configure the ffmpeg binary [:issue:`273`].
  - Filter .nomedia files with the source filename [:issue:`295`].
  - Populate title & description from IPTC image data [:issue:`297`].
  - Defer loading of leaflet js til late in the page [:issue:`298`].
  - Add compress_assets plugin [:issue:`300`].
  - Sidebar site logo image in Colorbox [:issue:`292`].
* Tue Nov 21 2017 jengelh@inai.de
- Compact description, rectify grammar.
* Sat Nov 18 2017 tbechtold@suse.com
- Initial packaging (version 1.3.0)
